@@ -3,9 +3,9 @@ package com.sun.tools.jdeps.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.20+8" },
-            { "jdk", "11.0.20" },
-            { "release", "11.0.20" },
+            { "full", "21.0.2+13-LTS" },
+            { "jdk", "21.0.2" },
+            { "release", "21.0.2" },
         };
     }
 }
